# CHANGELOG

<!-- version list -->

## v0.2.1 (2026-03-30)

### Bug Fixes

- Bump langchain-core
  ([`0c581af`](https://github.com/LinkupPlatform/langchain-linkup/commit/0c581afd4442936a77d0970b0a436cfa7d8b026a))

### Chores

- Format pyproject.toml with taplo
  ([`e1bff7d`](https://github.com/LinkupPlatform/langchain-linkup/commit/e1bff7df4258e3eab4854e28c1459564d9a4d1b9))

- Replace pre-commit with prek
  ([`19f7e88`](https://github.com/LinkupPlatform/langchain-linkup/commit/19f7e88218f799b464888834711835b8b33bf5bc))

- **uv**: Prevent install of too recent packages
  ([`f991959`](https://github.com/LinkupPlatform/langchain-linkup/commit/f9919595a21f4be3423f0c570c68535c68e83ae6))

- **uv**: Regenerate lock file
  ([`d86332c`](https://github.com/LinkupPlatform/langchain-linkup/commit/d86332cf72d7aedde181df44b56b1bcd7aa432e9))


## v0.2.0 (2026-03-06)

### Chores

- Add constraint on uv version
  ([`45b2f6d`](https://github.com/LinkupPlatform/langchain-linkup/commit/45b2f6df35213e93047d589a14157e5719febcd0))

- Setup semantic release
  ([`85497da`](https://github.com/LinkupPlatform/langchain-linkup/commit/85497daa47874a29193a9b04398f5bee006bdded))

- Update supported python versions
  ([`4877752`](https://github.com/LinkupPlatform/langchain-linkup/commit/48777521e0d5449b2c876a8804c1533e5b20e5bb))

- Update uv deps
  ([`d6920e2`](https://github.com/LinkupPlatform/langchain-linkup/commit/d6920e2cc7f4ec1cdbed074ab2dfa51c75a62b5d))

### Features

- Support latest SDK parameters
  ([`9f7ca0d`](https://github.com/LinkupPlatform/langchain-linkup/commit/9f7ca0d88745af94e9c8f77984328ac713ddd0f1))
